interminebio.RegionQuery

Package interminebio :: Class RegionQuery |
[hide private]
[frames] | no frames]

# Class RegionQuery

source code

           object --+
                    |
    SequenceDataQuery --+
                        |
                       RegionQuery

# Class for querying InterMine Webservices for Features in Genomic Intervals

This module allows you to construct queries that retrieve data about sequences and sequence features in biologically relevant formats, where those features are located overlapping genomic intervals.

The currently supported formats are UCSC-BED, GFF3, and FASTA.

These queries may also be used to construct lists with.

Instance Methods | [hide private]
__init__(self, service, organism, feature_types, regions, extension=0, is_interbase=False) | source code
_get_region_query(self) | source code
dict |
to_query_params(self) This method is a required part of the interface for creating lists. | source code
str |
get_list_upload_uri(self) This method is a required part of the interface for creating lists. | source code
Inherited from `SequenceDataQuery`: `bed`, `fasta`, `gff3` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| LIST_PATH = ``'``/regions/list``'``
| BED_PATH = ``'``/regions/bed``'``
| FASTA_PATH = ``'``/regions/fasta``'``
| GFF3_PATH = ``'``/regions/gff3``'``

Properties | [hide private]
| query
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, service, organism, feature_types, regions, extension=0, is_interbase=False) (Constructor) | source code
# Constructor
    >>> s = Service("www.flymine.org/query", "API-KEY")
    >>> org = "D. melanogaster"
    >>> regions = ["2L:14614843..14619614"]
    >>> feature_types = ["Exon", "Intron"]
    >>> q = RegionQuery(s, org, feature_types, regions)
    <interminebio.RegionQuery @xxx>
Parameters: `service` (intermine.webservice.Service) - The service to connect to. `organism` (str) - The short name of the organism to look within (eg: D. melanogaster) `feature_types` (list[str]) - The types of features to look for `regions` (list(str)) - The regions to search within, in chrX:start..end or chrX start end format `extension` (int) - A number of base-pairs to extend each region on either side (default: 0) `is_interbase` (boolean) - Whether to interpret the co-ordinates as interbase co-ordinates Overrides: object.__init__

Property Details | [hide private]

### query Get Method: unreachable.query(self)